nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

UsbOtg1Ctrl

Struct UsbOtg1Ctrl 

#[repr(transparent)]
pub struct UsbOtg1Ctrl(pub u32);
USB OTG1 Control Register

Tuple Fields

0: u32

Implementations

Source

impl UsbOtg1Ctrl

pub const fn over_cur_dis(&self) -> OverCurDis

Disable OTG1 Overcurrent Detection

pub const fn set_over_cur_dis(&mut self, val: OverCurDis)

Disable OTG1 Overcurrent Detection

pub const fn over_cur_pol(&self) -> OverCurPol

OTG1 Polarity of Overcurrent The polarity of OTG1 port overcurrent event

pub const fn set_over_cur_pol(&mut self, val: OverCurPol)

OTG1 Polarity of Overcurrent The polarity of OTG1 port overcurrent event

pub const fn pwr_pol(&self) -> PwrPol

OTG1 Power Polarity This bit should be set according to PMIC Power Pin polarity.

pub const fn set_pwr_pol(&mut self, val: PwrPol)

OTG1 Power Polarity This bit should be set according to PMIC Power Pin polarity.

pub const fn wie(&self) -> Wie

OTG1 Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up interrupt

pub const fn set_wie(&mut self, val: Wie)

OTG1 Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up interrupt

pub const fn wkup_sw_en(&self) -> WkupSwEn

OTG1 Software Wake-up Enable

pub const fn set_wkup_sw_en(&mut self, val: WkupSwEn)

OTG1 Software Wake-up Enable

pub const fn wkup_sw(&self) -> WkupSw

OTG1 Software Wake-up

pub const fn set_wkup_sw(&mut self, val: WkupSw)

OTG1 Software Wake-up

pub const fn wkup_id_en(&self) -> WkupIdEn

OTG1 Wake-up on ID change enable

pub const fn set_wkup_id_en(&mut self, val: WkupIdEn)

OTG1 Wake-up on ID change enable

pub const fn wkup_vbus_en(&self) -> WkupVbusEn

OTG1 wake-up on VBUS change enable

pub const fn set_wkup_vbus_en(&mut self, val: WkupVbusEn)

OTG1 wake-up on VBUS change enable

pub const fn wkup_dpdm_en(&self) -> WkupDpdmEn

Wake-up on DPDM change enable

pub const fn set_wkup_dpdm_en(&mut self, val: WkupDpdmEn)

Wake-up on DPDM change enable

pub const fn wir(&self) -> Wir

OTG1 Wake-up Interrupt Request This bit indicates that a wake-up interrupt request is received on the OTG1 port

pub const fn set_wir(&mut self, val: Wir)

OTG1 Wake-up Interrupt Request This bit indicates that a wake-up interrupt request is received on the OTG1 port